Entry

Enum Entry 

pub enum Entry<T: StateEnum, U> {
    State(U),
    Target(T),
    ExactTarget(T),
}
Return type of Substate::enter.

Represents either a successful state entry or a short circuit transition.

Variants



State(U)

State entry was successful, here is the newly constructed state.



Target(T)

A transition should be taken to the target state. See StateMachine::transition for transition semantics.



ExactTarget(T)

A transition should be taken to exactly the target state. See StateMachine::exact_transition for exact transition semantics.