Next

Enum Next 

pub enum Next<T: StateEnum> {
    None,
    Target(T),
    ExactTarget(T),
}
Represents either no action or some type of transition to new state.

Return type of multiple Substate methods.

Variants



None

No transition should be taken, stay in the current active state.



Target(T)

A transition should be taken to the target state. See StateMachine::transition for transition semantics.



ExactTarget(T)

A transition should be taken to exactly the target state. See StateMachine::exact_transition for exact transition semantics.