TopNode

Struct TopNode 

pub struct TopNode<T, U, V, W>
where T: StateEnum, U: StateMachineEvent, V: TopState<State = T, Event = U>, W: SubstateEnum<T, U, V>,
{ pub node: Node<T, U, V, W>, /* private fields */ }
The root node of a state tree.

Fields

node: Node<T, U, V, W>

Implementations

Source

impl<T, U, V, W> TopNode<T, U, V, W>
where T: StateEnum, U: StateMachineEvent, V: TopState<State = T, Event = U>, W: SubstateEnum<T, U, V>,

pub fn new(top_state: V, name: String) -> Self

Available on crate feature std only.

Make a new TopNode from a TopState and a machine name.

pub fn init(&mut self)

Perform the initial transition of this node.

pub fn update(&mut self)

Update this node and its active descendents.

pub fn top_down_update(&mut self)

Top-down update this node and its active descendents.

pub fn transition_quiet(&mut self, target: T, indent: bool, exact: bool)

Transition this node and its active descendents without logging the start and end of the transition.

pub fn transition(&mut self, target: T, indent: bool, exact: bool)

Transition this node and its active descendents.

pub fn state(&self) -> T

Get the current leaf state of this state tree.

pub fn name(&self) -> &str

Get the name of this machine.

pub fn set_name(&mut self, name: String)

Available on crate feature std only.

Set the name of this machine.

pub fn state_matches(&self, state: T) -> bool

Does this node or any active descendents match a given state?

pub fn handle_event(&mut self, event: &U)

Handle an event.